@@ -1,7 +1,6 @@
 pub mod queue;
 #[macro_use]
 pub mod sync;
-pub mod http;
 #[macro_use]
 pub mod errors;
 pub mod io;
@@ -12,4 +11,5 @@ pub mod time;
 pub mod map;
 pub mod strings;
 pub mod lazy;
-pub mod context;
\ No newline at end of file
+pub mod context;
+pub mod wrapper;
\ No newline at end of file
